@@ -1,6 +1,6 @@
 import pandas as pd
 import click
-from xpandas import module
+from xpandas.module import *
 
 
 def get_cmd():
@@ -27,13 +27,13 @@ def run(csv):
     print('csv shape: [%s rows x %s columns]' % df.shape)
 
     if cmd == 's':
-        module.split_csv(df, csv)
+        split_csv(df, csv)
     elif cmd == 'c':
-        module.chunk_csv(df, csv)
+        chunk_csv(df, csv)
     elif cmd == 't':
-        module.top_csv(df, csv)
+        top_csv(df, csv)
     elif cmd == 'e':
-        module.extract_csv(df, csv)
+        extract_csv(df, csv)
 
 
 if __name__ == '__main__':
